from setuptools import setup

setup(
    name="behaveai",
    version="0.0.0",
    description="behaveai",
    author="Your Name",
    author_email="zdunekhere@gmail.com",
    license="MIT",
    packages=[],
)
